import 'dart:io';

import 'color.dart';

String hexToIntHex(String color) {
  return color.replaceFirst('#', '0xFF');
}

List<ColorSwatchProperty> parseJsonTheme(Map<String, dynamic> jsonMap) {
  // store results by categorize it using map to easily find it
  Map<String, ColorSwatchProperty> results = Map<String, ColorSwatchProperty>();

  // loop each line of json
  jsonMap.forEach((key, value) {
    ColorProperty parsed = ColorProperty.fromLine(key, value);

    // check if the name has created
    if (!results.containsKey(parsed.name)) {
      results[parsed.name] = ColorSwatchProperty();
    }

    // add the parsed to swatches
    results[parsed.name]!.swatches.add(parsed);

    // if index is 600 for basic, or 500 for other, add it as primary
    if (parsed.type == ColorType.basic && parsed.index == '600') {
      results[parsed.name]!.primary = parsed;
    } else if (parsed.type != ColorType.basic && parsed.index == '500') {
      results[parsed.name]!.primary = parsed;
    }
  });

  return results.values.toList();
}

void writeReplaceFile(File file, String content) {
  // check if exists, delete it first
  if (file.existsSync()) {
    // assume replace
    file.deleteSync();
  }

  file.createSync();
  file.writeAsStringSync(content);
}
